```
Usage: vcd gateway configure-rate-limits update [OPTIONS] <gateway name>

Options:
  -r <external network> <rate limit start> <rate limit end>
                                  Updates existing rate limits  [required]
  -h, --help                      Show this message and exit.

```
